@@ -1,5 +1,5 @@
 __author__ = 'Daniel Lindsley'
-__version__ = (0, 4, 0)
+__version__ = (2, 0, 0)
 __license__ = 'BSD'
 
 
@@ -8,12 +8,4 @@ def get_version():
 
 
 # Constants
-HASH_WIDTH = 6
-ADDED = 'A'
-DELETED = 'D'
 SEPARATOR = '::'
-
-# TODO:
-# * LRU cache
-# * Maybe add ``flock`` & exponential back-off in.
-# * Docs
